/*===========================================================================*
 * gdk_graphics.c                                                            *
 *                                                                           *
 *      graphical interface using gdk                                        *
 *                                                                           *
 * EXPORTED PROCEDURES:                                                      *
 *      GdkGC *get_gdk_pen(GdkWindow *window,                                *
 *                         gdouble red, gdouble green, gdouble blue)         *
 *      void gdk_circle(GdkDrawable *drawable, GdkGC* gc,                    *
 *                      gint x, gint y, gint rad, gboolean fill)             *
 *      void gdk_rectangle(GdkDrawable *drawable, GdkGC* gc,                 *
 *                         gint x1, gint y1, gint x2, gint y2, gboolean fill)*
 *      void gdk_point (GdkDrawable *drawable, GdkGC* gc, gint x, gint y)    *
 *      void gdk_plot (GdkDrawable *drawable, GdkGC* gc, gfloat x, gint y)   *
 *                    gfloat rad)                                            *
 *                                                            (by A. Miyake) *
 *===========================================================================*/
#include <gtk/gtk.h>
#include <math.h>

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif
#include "intl.h"

/*===========================================================================*
 * (EXPORTED PROCEDURE)                                                      *
 *                   get_pen                                                 *
 *===========================================================================*/
GdkGC *
get_gdk_pen(GdkWindow *window, gdouble red, gdouble green, gdouble blue)
{
   GdkColor *c= (GdkColor *)g_malloc(sizeof(GdkColor));    
   GdkGC *gc = gdk_gc_new(window);

   c->red = 0xffff*red; c->green = 0xffff*green; c->blue = 0xffff*blue;
   gdk_color_alloc(gdk_colormap_get_system(), c);
   gdk_gc_set_foreground(gc, c);
   return gc;
}

/*===========================================================================*
 * (EXPORTED PROCEDURE)                                                      *
 *                   gdk_circle                                              *
 *===========================================================================*/
void 
gdk_circle(GdkDrawable *drawable, GdkGC* gc, int x, gint y, gint rad, 
	   gboolean fill)
{
   gdk_draw_arc(drawable, gc, fill, x-rad, y-rad, 2*rad, 2*rad, 0, 360*64);
}


/*===========================================================================*
 * (EXPORTED PROCEDURE)                                                      *
 *                   gdk_rectangle                                           *
 *===========================================================================*/
void 
gdk_rectangle(GdkDrawable *drawable, GdkGC* gc, gint x1, gint y1, 
	      gint x2, gint y2, gboolean fill)
{
   gint xstart, ystart;
   gint xsize, ysize;
   
   if(x1 < x2) { xstart = x1; xsize = x2 - x1; }
   else        { xstart = x2; xsize = x1 - x2; }
   if(y1 < y2) { ystart = y1; ysize = y2 - y1; }
   else        { ystart = y2; ysize = y1 - y2; }

   gdk_draw_rectangle(drawable, gc, fill, xstart, ystart, xsize, ysize);   
} 
  
/*===========================================================================*
 * (EXPORTED PROCEDURE)                                                      *
 *                   gdk_plot                                                *
 *===========================================================================*/
void 
gdk_point(GdkDrawable *drawable, GdkGC* gc, int x, gint y )
{
   gdk_draw_point(drawable, gc, x, y);
}


/*===========================================================================*
 * (EXPORTED PROCEDURE)                                                      *
 *                   gdk_plot                                                *
 *===========================================================================*/
void 
gdk_plot(GdkDrawable *drawable, GdkGC* gc, gfloat x, gfloat y, gfloat rad) 
{
   int i, j;
   for(j = floor(y-rad); j <= ceil(y+rad); j++)
   {
      for(i = floor(x-rad); i <= ceil(x+rad); i++)
      {
	 if( (i-x)*(i-x) + (j-y)*(j-y) < rad*rad )
	   gdk_draw_point(drawable, gc, i, j);
      }
   }
}
