/*===========================================================================*
 * main_window.c                                                             *
 *                                                                           *
 *      Creating Main Window of cono_map                                     *
 *                                                                           *
 * EXPORTED PROCEDURES:                                                      *
 *      GtkWidget* MainWindow ()                                             *
 *      void MessageDialog (gchar* message)                                  *
 *                                                            (by A. Miyake) *
 *===========================================================================*/

#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif

#include <gtk/gtk.h>
#include "cono_map.h"
#include "widget_set.h"

#include "intl.h"

/*====================*
 * External Functions *
 *====================*/
extern void ImageDrawing();    /*from image_drawing.c*/
extern void createSelectButtonFrame(GtkWidget *);
extern void createStereoFrame(GtkWidget *);
extern void createOrientationFrame(GtkWidget *);
extern void createOpticFeatureFrame(GtkWidget *);
extern void createOtherParametFrame(GtkWidget *);


/*======================================================================*
 * Exported Procedure                                                   *
 *                                                                      *
 *                     MainWindow                                       *
 *======================================================================*/
 
GtkWidget*
MainWindow ()
{
  GtkWidget *MainWindow;
  GtkWidget *MainVBox, *ActionBox;
  GtkWidget *HBox, *VBox1, *VBox2;
  GtkWidget *DrawingButton, *FinishButton;

  MainWindow = gtk_dialog_new ();
  gtk_widget_set_uposition (MainWindow, 6, -2);
  gtk_window_set_title (GTK_WINDOW (MainWindow), "ConoMap (Version 2.0.0)");

  MainVBox = GTK_DIALOG(MainWindow)->vbox;
  ActionBox = GTK_DIALOG(MainWindow)->action_area;
  gtk_container_set_border_width (GTK_CONTAINER (ActionBox), 5);

  createSelectButtonFrame(MainVBox);

  HBox = gtk_hbox_new(FALSE, 0);
  gtk_container_add(GTK_CONTAINER(MainVBox), HBox);

  VBox1 = gtk_vbox_new(FALSE, 0);
  VBox2 = gtk_vbox_new(FALSE, 0);
  gtk_container_add(GTK_CONTAINER(HBox), VBox1);
  gtk_container_add(GTK_CONTAINER(HBox), VBox2);

  createOpticFeatureFrame(VBox1);
  createOrientationFrame(VBox1);
  createOtherParametFrame(VBox2);
  createStereoFrame(VBox2);
  
  DrawingButton = pack_button(ActionBox, _("Draw"));
  FinishButton = pack_button(ActionBox, _("Quit"));

  /**************** signal conects **************************************/
  gtk_signal_connect (GTK_OBJECT (MainWindow), "destroy",
		      GTK_SIGNAL_FUNC (gtk_exit), NULL);
  gtk_signal_connect (GTK_OBJECT (DrawingButton), "clicked",
                      GTK_SIGNAL_FUNC (ImageDrawing), NULL);
  gtk_signal_connect (GTK_OBJECT (FinishButton), "clicked",
		      GTK_SIGNAL_FUNC (gtk_main_quit), NULL);

  gtk_widget_show_all(MainWindow);
  return MainWindow;
}
  
/*======================================================================*
 * Exported Procedure                                                   *
 *                                                                      *
 *                     MessageDialog                                    *
 *======================================================================*/

void MessageDialog (gchar* message)
{
  GtkWidget *MessageDialog;
  GtkWidget *button, *label;

  MessageDialog = gtk_dialog_new ();
  gtk_window_set_title (GTK_WINDOW (MessageDialog), "ConoMap - Message");

  button = pack_button(GTK_DIALOG (MessageDialog)->action_area, _("OK"));
  label = pack_label(GTK_DIALOG (MessageDialog)->vbox, message, 10);

  gtk_container_set_border_width(
                  GTK_CONTAINER( GTK_DIALOG (MessageDialog)->vbox), 10);

  gtk_signal_connect_object (GTK_OBJECT (button), "clicked",                   
			     GTK_SIGNAL_FUNC (gtk_widget_destroy), 
			     GTK_OBJECT(gtk_widget_get_toplevel(button)));

  gtk_widget_show_all(MessageDialog);
  gtk_grab_add(MessageDialog);
}  

